@@ -76,7 +76,7 @@ cateditmatrix <- function(x, sep=":", env=parent.frame()){
 as.character.cateditmatrix <- function(x, asIfStatement=FALSE, ...){
   # empty cateditmatrix?
   if (length(x) == 0) 
-    return(str(x))
+    return(str.editmatrix(x))
   
   if (isTRUE(asIfStatement)){
     A <- getA(x)
